@@ -14,7 +14,7 @@
 ## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with readBrukerFlexData. If not, see <http://www.gnu.org/licenses/>
+## along with readBrukerFlexData. If not, see <https://www.gnu.org/licenses/>
 
 #' The readBrukerFlexData Package
 #'
@@ -26,28 +26,13 @@
 #' \cr \cr
 #' All trademarks are owned by or licensed to Bruker Daltonics.
 #'
-#' \tabular{ll}{
-#'
-#' Package: \tab readBrukerFlexData \cr
-#'
-#' Version: \tab 1.8.3\cr
-#'
-#' Date: \tab 2016-11-29\cr
-#'
-#' License: \tab GPL (>= 3)\cr
-#'
-#' URL: \tab \url{https://github.com/sgibb/readBrukerFlexData}\cr
-#'
-#' }
-#'
-#' @docType package
 #' @name readBrukerFlexData-package
 #' @author Sebastian Gibb \email{mail@@sebastiangibb.de}
 #' @references \url{https://github.com/sgibb/readBrukerFlexData}
 #' @keywords package
 #' @rdname readBrukerFlexData-package
 #'
-NULL
+"_PACKAGE"
 
 #' These functions are defunct and no longer available.
 #'
